/* util-app.c generated by valac 0.18.0.79-04df6, the Vala compiler
 * generated from util-app.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gdk/gdk.h>
#include <clutter/clutter.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <libcommon.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gio/gio.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <config.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <unistd.h>
#include <cairo.h>
#include <libgd/gd.h>

#define _gtk_widget_path_unref0(var) ((var == NULL) ? NULL : (var = (gtk_widget_path_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block56Data Block56Data;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
typedef struct _Block57Data Block57Data;
#define _xmlFreeParserCtxt0(var) ((var == NULL) ? NULL : (var = (xmlFreeParserCtxt (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _xmlXPathFreeContext0(var) ((var == NULL) ? NULL : (var = (xmlXPathFreeContext (var), NULL)))
typedef struct _Block58Data Block58Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesCheckSelinuxContextDefaultData BoxesCheckSelinuxContextDefaultData;
typedef struct _BoxesCheckLibvirtKvmData BoxesCheckLibvirtKvmData;
typedef struct _BoxesCheckCpuVtCapabilityData BoxesCheckCpuVtCapabilityData;
typedef struct _BoxesCheckModuleKvmLoadedData BoxesCheckModuleKvmLoadedData;
typedef struct _BoxesCheckStoragePoolData BoxesCheckStoragePoolData;
typedef struct _Block59Data Block59Data;
typedef struct _BoxesCopyFileData BoxesCopyFileData;

#define BOXES_TYPE_CPU_ARCH_COMPATIBITY (boxes_cpu_arch_compatibity_get_type ())

struct _Block56Data {
	int _ref_count_;
	GtkTreeView* tree_view;
};

struct _Block57Data {
	int _ref_count_;
	GtkIconView* icon_view;
};

struct _Block58Data {
	int _ref_count_;
	ClutterActor* actor;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef void (*BoxesActorFunc) (ClutterActor* actor, void* user_data);
struct _BoxesCheckSelinuxContextDefaultData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** argv;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError* _error_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GError* _vala1__error_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _BoxesCheckLibvirtKvmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gchar* standard_output;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gchar** argv;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* kvm;
	const gchar* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	GError* _error_;
	GError* _vala1__error_;
	GError* _tmp10_;
	const gchar* _tmp11_;
	GError * _inner_error_;
};

struct _BoxesCheckCpuVtCapabilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* _tmp0_;
	GFile* file;
	GFile* _tmp1_;
	GFileInputStream* _tmp2_;
	GFileInputStream* _tmp3_;
	GFileInputStream* _tmp4_;
	GDataInputStream* _tmp5_;
	GDataInputStream* _tmp6_;
	GDataInputStream* stream;
	gchar* line;
	GDataInputStream* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GError* _error_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckModuleKvmLoadedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* _tmp0_;
	GFile* file;
	GFile* _tmp1_;
	GFileInputStream* _tmp2_;
	GFileInputStream* _tmp3_;
	GFileInputStream* _tmp4_;
	GDataInputStream* _tmp5_;
	GDataInputStream* _tmp6_;
	GDataInputStream* stream;
	gchar* line;
	GDataInputStream* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GError* _error_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* pool_path;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gchar** argv;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	GError* _error_;
	GError* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	const gchar* _tmp21_;
	const gchar* _tmp22_;
	gchar* _tmp23_;
	const gchar* _tmp24_;
	gint _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	GError * _inner_error_;
};

struct _Block59Data {
	int _ref_count_;
	GtkWidget* widget;
};

struct _BoxesCopyFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GFile* src_file;
	GFile* dest_file;
	GCancellable* cancellable;
	GFile* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GFile* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GFile* _tmp6_;
	GFile* _tmp7_;
	GCancellable* _tmp8_;
	GFile* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	GFile* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	GError* _error_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE = -1,
	BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL = 0,
	BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE = 1,
	BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE_DIFF_WORDSIZE = 2
} BoxesCPUArchCompatibity;


extern BoxesApp* boxes_app_app;

void boxes_gdk_rgba_to_clutter_color (GdkRGBA* gdk_rgba, ClutterColor* result);
void boxes_get_boxes_bg_color (GdkRGBA* result);
void boxes_get_color (const gchar* desc, GdkRGBA* result);
void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate);
static Block56Data* block56_data_ref (Block56Data* _data56_);
static void block56_data_unref (void * _userdata_);
static gboolean ____lambda43_ (Block56Data* _data56_, GtkWidget* w, GdkEventButton* event);
static gboolean _____lambda43__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
void boxes_icon_view_activate_on_single_click (GtkIconView* icon_view, gboolean should_activate);
static Block57Data* block57_data_ref (Block57Data* _data57_);
static void block57_data_unref (void * _userdata_);
static gboolean ____lambda9_ (Block57Data* _data57_, GtkWidget* w, GdkEventButton* event);
static gboolean _____lambda9__gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
void boxes_allocate_actor_no_animation (ClutterActor* actor, gfloat x, gfloat y, gfloat width, gfloat height);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
static Block58Data* block58_data_ref (Block58Data* _data58_);
static void block58_data_unref (void * _userdata_);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void __lambda130_ (Block58Data* _data58_);
static void ___lambda130__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self);
void boxes_actor_add (ClutterActor* actor, ClutterActor* container);
void boxes_actor_remove (ClutterActor* actor);
OsinfoDevice* boxes_get_os_device_by_prop (OsinfoOs* os, const gchar* prop_name, const gchar* prop_value);
GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size);
void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size);
gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain);
static void boxes_check_selinux_context_default_data_free (gpointer _data);
void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_);
static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_libvirt_kvm_data_free (gpointer _data);
void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_);
static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_);
static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_cpu_vt_capability_data_free (gpointer _data);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_);
static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_module_kvm_loaded_data_free (gpointer _data);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_);
static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_storage_pool_data_free (gpointer _data);
void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_);
static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf);
static guint8* _vala_array_dup5 (guint8* self, int length);
void boxes_draw_as_css_box (GtkWidget* widget);
static Block59Data* block59_data_ref (Block59Data* _data59_);
static void block59_data_unref (void * _userdata_);
static gboolean __lambda166_ (Block59Data* _data59_, cairo_t* cr);
static gboolean ___lambda166__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
static void boxes_copy_file_data_free (gpointer _data);
void boxes_copy_file (GFile* src_file, GFile* dest_file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_copy_file_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_copy_file_co (BoxesCopyFileData* _data_);
static void boxes_copy_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_cpu_arch_compatibity_get_type (void) G_GNUC_CONST;
BoxesCPUArchCompatibity boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2);
void uuid_generate (guchar* uuid);
void uuid_unparse (guchar* uuid, guchar* output);
gchar* boxes_uuid_generate (void);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static GRegex* _tmp_regex_0 = NULL;
static GRegex* _tmp_regex_1 = NULL;

void boxes_gdk_rgba_to_clutter_color (GdkRGBA* gdk_rgba, ClutterColor* result) {
	GdkRGBA _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_ = 0.0;
	GdkRGBA _tmp3_;
	gdouble _tmp4_;
	gdouble _tmp5_ = 0.0;
	GdkRGBA _tmp6_;
	gdouble _tmp7_;
	gdouble _tmp8_ = 0.0;
	GdkRGBA _tmp9_;
	gdouble _tmp10_;
	gdouble _tmp11_ = 0.0;
	ClutterColor _tmp12_ = {0};
	ClutterColor color;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (gdk_rgba != NULL);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = *gdk_rgba;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_.red;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = CLAMP (_tmp1_ * 255, (gdouble) 0, (gdouble) 255);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = *gdk_rgba;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _tmp3_.green;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = CLAMP (_tmp4_ * 255, (gdouble) 0, (gdouble) 255);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = *gdk_rgba;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_.blue;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = CLAMP (_tmp7_ * 255, (gdouble) 0, (gdouble) 255);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = *gdk_rgba;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = _tmp9_.alpha;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = CLAMP (_tmp10_ * 255, (gdouble) 0, (gdouble) 255);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.red = (guint8) _tmp2_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.green = (guint8) _tmp5_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.blue = (guint8) _tmp8_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.alpha = (guint8) _tmp11_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	color = _tmp12_;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = color;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 675 "util-app.c"
}


void boxes_get_boxes_bg_color (GdkRGBA* result) {
	GtkStyleContext* _tmp0_;
	GtkStyleContext* style;
	GtkWidgetPath* _tmp1_;
	GtkWidgetPath* path;
	GdkRGBA _tmp2_ = {0};
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = gtk_style_context_new ();
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	style = _tmp0_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_path_new ();
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp1_;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_widget_path_append_type (path, GTK_TYPE_WINDOW);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_set_path (style, path);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_add_class (style, "boxes-bg");
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_get_background_color (style, 0, &_tmp2_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = _tmp2_;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_gtk_widget_path_unref0 (path);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (style);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 709 "util-app.c"
}


void boxes_get_color (const gchar* desc, GdkRGBA* result) {
	GdkRGBA color = {0};
	const gchar* _tmp0_;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (desc != NULL);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	memset (&color, 0, sizeof (GdkRGBA));
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = desc;
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gdk_rgba_parse (&color, _tmp0_);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = color;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 728 "util-app.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return self ? g_object_ref (self) : NULL;
#line 735 "util-app.c"
}


static Block56Data* block56_data_ref (Block56Data* _data56_) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data56_->_ref_count_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data56_;
#line 744 "util-app.c"
}


static void block56_data_unref (void * _userdata_) {
	Block56Data* _data56_;
	_data56_ = (Block56Data*) _userdata_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data56_->_ref_count_)) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data56_->tree_view);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block56Data, _data56_);
#line 757 "util-app.c"
	}
}


static gboolean ____lambda43_ (Block56Data* _data56_, GtkWidget* w, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GtkTreeViewColumn* column = NULL;
	gint x = 0;
	gint y = 0;
	gboolean _tmp0_ = FALSE;
	GdkEventButton _tmp1_;
	guint _tmp2_;
	gboolean _tmp5_;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (w != NULL, FALSE);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = *event;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _tmp1_.button;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == ((guint) 1)) {
#line 782 "util-app.c"
		GdkEventButton _tmp3_;
		GdkEventType _tmp4_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = *event;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp3_.type;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp4_ == GDK_BUTTON_PRESS;
#line 791 "util-app.c"
	} else {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = FALSE;
#line 795 "util-app.c"
	}
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp0_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_) {
#line 801 "util-app.c"
		GtkTreeView* _tmp6_;
		GdkEventButton _tmp7_;
		gdouble _tmp8_;
		GdkEventButton _tmp9_;
		gdouble _tmp10_;
		GtkTreePath* _tmp11_ = NULL;
		GtkTreeViewColumn* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		GtkTreePath* _tmp15_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = _data56_->tree_view;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = *event;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _tmp7_.x;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = *event;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = _tmp9_.y;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_tree_view_get_path_at_pos (_tmp6_, (gint) _tmp8_, (gint) _tmp10_, &_tmp11_, &_tmp12_, &_tmp13_, &_tmp14_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_gtk_tree_path_free0 (path);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp11_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		column = _tmp12_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		x = _tmp13_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		y = _tmp14_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = path;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp15_ != NULL) {
#line 838 "util-app.c"
			GtkTreeView* _tmp16_;
			GtkTreePath* _tmp17_;
			GtkTreeViewColumn* _tmp18_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = _data56_->tree_view;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = path;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = column;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			gtk_tree_view_row_activated (_tmp16_, _tmp17_, _tmp18_);
#line 850 "util-app.c"
		}
	}
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_gtk_tree_path_free0 (path);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 859 "util-app.c"
}


static gboolean _____lambda43__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = ____lambda43_ (self, _sender, event);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 868 "util-app.c"
}


void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate) {
	Block56Data* _data56_;
	GtkTreeView* _tmp0_;
	GtkTreeView* _tmp1_;
	GtkTreeView* _tmp2_;
	gconstpointer _tmp3_ = NULL;
	gulong id;
	gboolean _tmp4_ = FALSE;
	gulong _tmp5_;
	gboolean _tmp7_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (tree_view != NULL);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data56_ = g_slice_new0 (Block56Data);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data56_->_ref_count_ = 1;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = tree_view;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data56_->tree_view);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data56_->tree_view = _tmp1_;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data56_->tree_view;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "boxes-tree-view-activate");
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (gulong) ((guintptr) _tmp3_);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = id;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_ != ((gulong) 0)) {
#line 906 "util-app.c"
		gboolean _tmp6_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = should_activate;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp6_ == FALSE;
#line 912 "util-app.c"
	} else {
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = FALSE;
#line 916 "util-app.c"
	}
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp4_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_) {
#line 922 "util-app.c"
		GtkTreeView* _tmp8_;
		gulong _tmp9_;
		GtkTreeView* _tmp10_;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _data56_->tree_view;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = id;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = _data56_->tree_view;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_set_data_full ((GObject*) _tmp10_, "boxes-tree-view-activate", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 936 "util-app.c"
	} else {
		gboolean _tmp11_ = FALSE;
		gulong _tmp12_;
		gboolean _tmp14_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = id;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp12_ == ((gulong) 0)) {
#line 945 "util-app.c"
			gboolean _tmp13_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp13_ = should_activate;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = _tmp13_;
#line 951 "util-app.c"
		} else {
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = FALSE;
#line 955 "util-app.c"
		}
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp11_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp14_) {
#line 961 "util-app.c"
			GtkTreeView* _tmp15_;
			gulong _tmp16_ = 0UL;
			GtkTreeView* _tmp17_;
			gulong _tmp18_;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp15_ = _data56_->tree_view;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = g_signal_connect_data ((GtkWidget*) _tmp15_, "button-press-event", (GCallback) _____lambda43__gtk_widget_button_press_event, block56_data_ref (_data56_), (GClosureNotify) block56_data_unref, 0);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			id = _tmp16_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = _data56_->tree_view;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = id;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_set_data_full ((GObject*) _tmp17_, "boxes-tree-view-activate", (gpointer) ((guintptr) _tmp18_), NULL);
#line 978 "util-app.c"
		}
	}
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	block56_data_unref (_data56_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data56_ = NULL;
#line 985 "util-app.c"
}


static Block57Data* block57_data_ref (Block57Data* _data57_) {
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data57_->_ref_count_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data57_;
#line 994 "util-app.c"
}


static void block57_data_unref (void * _userdata_) {
	Block57Data* _data57_;
	_data57_ = (Block57Data*) _userdata_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data57_->_ref_count_)) {
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data57_->icon_view);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block57Data, _data57_);
#line 1007 "util-app.c"
	}
}


static gpointer _gtk_tree_path_copy0 (gpointer self) {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return self ? gtk_tree_path_copy (self) : NULL;
#line 1015 "util-app.c"
}


static gboolean ____lambda9_ (Block57Data* _data57_, GtkWidget* w, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GdkEventButton _tmp0_;
	guint _tmp1_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (w != NULL, FALSE);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = *event;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_.button;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp1_ == ((guint) 1)) {
#line 1034 "util-app.c"
		GtkIconView* _tmp2_;
		GdkEventButton _tmp3_;
		gdouble _tmp4_;
		GdkEventButton _tmp5_;
		gdouble _tmp6_;
		GtkTreePath* _tmp7_ = NULL;
		GtkTreePath* _tmp8_;
		GtkTreePath* _tmp9_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = _data57_->icon_view;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = *event;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp3_.x;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = *event;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = _tmp5_.y;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = gtk_icon_view_get_path_at_pos (_tmp2_, (gint) _tmp4_, (gint) _tmp6_);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _gtk_tree_path_copy0 (_tmp7_);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_gtk_tree_path_free0 (path);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp8_;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = path;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp9_ != NULL) {
#line 1065 "util-app.c"
			GtkIconView* _tmp10_;
			GtkTreePath* _tmp11_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp10_ = _data57_->icon_view;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = path;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			gtk_icon_view_item_activated (_tmp10_, _tmp11_);
#line 1074 "util-app.c"
		}
	}
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_gtk_tree_path_free0 (path);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1083 "util-app.c"
}


static gboolean _____lambda9__gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = ____lambda9_ (self, _sender, event);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1092 "util-app.c"
}


void boxes_icon_view_activate_on_single_click (GtkIconView* icon_view, gboolean should_activate) {
	Block57Data* _data57_;
	GtkIconView* _tmp0_;
	GtkIconView* _tmp1_;
	GtkIconView* _tmp2_;
	gconstpointer _tmp3_ = NULL;
	gulong id;
	gboolean _tmp4_ = FALSE;
	gulong _tmp5_;
	gboolean _tmp7_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (icon_view != NULL);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data57_ = g_slice_new0 (Block57Data);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data57_->_ref_count_ = 1;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = icon_view;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data57_->icon_view);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data57_->icon_view = _tmp1_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data57_->icon_view;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "boxes-icon-view-activate");
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (gulong) ((guintptr) _tmp3_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = id;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_ != ((gulong) 0)) {
#line 1130 "util-app.c"
		gboolean _tmp6_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = should_activate;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp6_ == FALSE;
#line 1136 "util-app.c"
	} else {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = FALSE;
#line 1140 "util-app.c"
	}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp4_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_) {
#line 1146 "util-app.c"
		GtkIconView* _tmp8_;
		gulong _tmp9_;
		GtkIconView* _tmp10_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _data57_->icon_view;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = id;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = _data57_->icon_view;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_set_data_full ((GObject*) _tmp10_, "boxes-icon-view-activate", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 1160 "util-app.c"
	} else {
		gboolean _tmp11_ = FALSE;
		gulong _tmp12_;
		gboolean _tmp14_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = id;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp12_ == ((gulong) 0)) {
#line 1169 "util-app.c"
			gboolean _tmp13_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp13_ = should_activate;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = _tmp13_;
#line 1175 "util-app.c"
		} else {
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = FALSE;
#line 1179 "util-app.c"
		}
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp11_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp14_) {
#line 1185 "util-app.c"
			GtkIconView* _tmp15_;
			gulong _tmp16_ = 0UL;
			GtkIconView* _tmp17_;
			gulong _tmp18_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp15_ = _data57_->icon_view;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = g_signal_connect_data ((GtkWidget*) _tmp15_, "button-release-event", (GCallback) _____lambda9__gtk_widget_button_release_event, block57_data_ref (_data57_), (GClosureNotify) block57_data_unref, 0);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			id = _tmp16_;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = _data57_->icon_view;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = id;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_set_data_full ((GObject*) _tmp17_, "boxes-icon-view-activate", (gpointer) ((guintptr) _tmp18_), NULL);
#line 1202 "util-app.c"
		}
	}
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	block57_data_unref (_data57_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data57_ = NULL;
#line 1209 "util-app.c"
}


gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error) {
	gchar* result = NULL;
	xmlParserCtxt* _tmp0_;
	xmlParserCtxt* parser;
	xmlParserCtxt* _tmp1_;
	const gchar* _tmp2_;
	xmlDoc* _tmp3_ = NULL;
	xmlDoc* doc;
	xmlDoc* _tmp4_;
	xmlDoc* _tmp6_;
	xmlXPathContext* _tmp7_;
	xmlXPathContext* ctxt;
	xmlXPathContext* _tmp8_;
	const gchar* _tmp9_;
	xmlXPathObject* _tmp10_ = NULL;
	xmlXPathObject* obj;
	gboolean _tmp11_ = FALSE;
	xmlXPathObject* _tmp12_;
	gboolean _tmp15_;
	xmlXPathObject* _tmp22_;
	xmlXPathObjectType _tmp23_;
	xmlXPathObject* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	GError * _inner_error_ = NULL;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xmldoc != NULL, NULL);
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xpath != NULL, NULL);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = xmlNewParserCtxt ();
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	parser = _tmp0_;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = parser;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = xmldoc;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = xmlCtxtReadDoc (_tmp1_, _tmp2_, "doc.xml", NULL, 0);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	doc = _tmp3_;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = doc;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp4_ == NULL) {
#line 1258 "util-app.c"
		GError* _tmp5_;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Can't parse XML doc");
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp5_;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1272 "util-app.c"
		} else {
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1282 "util-app.c"
		}
	}
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = doc;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = xmlXPathNewContext (_tmp6_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	ctxt = _tmp7_;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = ctxt;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = xpath;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = xmlXPathEval (_tmp9_, _tmp8_);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	obj = _tmp10_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = obj;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp12_ == NULL) {
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = TRUE;
#line 1305 "util-app.c"
	} else {
		xmlXPathObject* _tmp13_;
		const gchar* _tmp14_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = obj;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp13_->stringval;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = _tmp14_ == NULL;
#line 1315 "util-app.c"
	}
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = _tmp11_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp15_) {
#line 1321 "util-app.c"
		gboolean _tmp16_;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = required;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp16_) {
#line 1327 "util-app.c"
			const gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			GError* _tmp20_;
			GError* _tmp21_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = xpath;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = g_strconcat ("Failed to extract xpath ", _tmp17_, NULL);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = _tmp18_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp20_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp19_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp21_ = _tmp20_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_tmp19_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = _tmp21_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_propagate_error (error, _inner_error_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 1357 "util-app.c"
			} else {
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_clear_error (&_inner_error_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 1369 "util-app.c"
			}
		} else {
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = NULL;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 1380 "util-app.c"
		}
	}
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp22_ = obj;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp23_ = _tmp22_->type;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp23_ != XPATH_STRING) {
#line 1389 "util-app.c"
		const gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		GError* _tmp27_;
		GError* _tmp28_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp24_ = xpath;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = g_strconcat ("Failed to extract xpath ", _tmp24_, NULL);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = _tmp25_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp26_);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = _tmp27_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp26_);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp28_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1419 "util-app.c"
		} else {
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1431 "util-app.c"
		}
	}
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp29_ = obj;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp30_ = _tmp29_->stringval;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp31_ = g_strdup (_tmp30_);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp31_;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlXPathFreeContext0 (ctxt);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlFreeParserCtxt0 (parser);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1448 "util-app.c"
}


void boxes_allocate_actor_no_animation (ClutterActor* actor, gfloat x, gfloat y, gfloat width, gfloat height) {
	ClutterActor* _tmp0_;
	guint _tmp1_ = 0U;
	guint old_duration;
	ClutterActor* _tmp2_;
	gfloat _tmp3_;
	gfloat _tmp4_;
	gfloat _tmp5_;
	gfloat _tmp6_;
	gfloat _tmp7_;
	gfloat _tmp8_;
	ClutterActorBox _tmp9_ = {0};
	ClutterActorBox box;
	ClutterActor* _tmp10_;
	ClutterActorBox _tmp11_;
	ClutterActor* _tmp12_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = clutter_actor_get_easing_duration (_tmp0_);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	old_duration = _tmp1_;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = actor;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_easing_duration (_tmp2_, (guint) 0);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = x;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = y;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = x;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = width;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = y;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = height;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.x1 = _tmp3_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.y1 = _tmp4_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.x2 = _tmp5_ + _tmp6_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.y2 = _tmp7_ + _tmp8_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	box = _tmp9_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = actor;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = box;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_allocate (_tmp10_, &_tmp11_, 0);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = actor;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_easing_duration (_tmp12_, old_duration);
#line 1512 "util-app.c"
}


static Block58Data* block58_data_ref (Block58Data* _data58_) {
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data58_->_ref_count_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data58_;
#line 1521 "util-app.c"
}


static void block58_data_unref (void * _userdata_) {
	Block58Data* _data58_;
	_data58_ = (Block58Data*) _userdata_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data58_->_ref_count_)) {
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data58_->actor);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block58Data, _data58_);
#line 1534 "util-app.c"
	}
}


static void __lambda130_ (Block58Data* _data58_) {
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_;
	guint _tmp2_;
	guint _tmp3_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _data58_->actor;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _data58_->actor;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = clutter_actor_get_opacity (_tmp1_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_set (_tmp0_, "visible", _tmp3_ != ((guint) 0), NULL);
#line 1554 "util-app.c"
}


static void ___lambda130__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self) {
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	__lambda130_ (self);
#line 1561 "util-app.c"
}


void boxes_fade_actor (ClutterActor* actor, guint opacity) {
	Block58Data* _data58_;
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_;
	guint _tmp2_;
	ClutterActor* _tmp4_;
	guint _tmp5_;
	ClutterActor* _tmp6_;
	ClutterActor* _tmp7_;
	ClutterActor* _tmp8_;
	BoxesApp* _tmp9_;
	guint _tmp10_;
	ClutterActor* _tmp11_;
	guint _tmp12_;
	ClutterActor* _tmp13_;
	ClutterTransition* _tmp14_ = NULL;
	ClutterTransition* _tmp15_;
	ClutterTransition* t;
	ClutterActor* _tmp16_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_ = g_slice_new0 (Block58Data);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_->_ref_count_ = 1;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data58_->actor);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_->actor = _tmp1_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = opacity;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 1602 "util-app.c"
		ClutterActor* _tmp3_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = _data58_->actor;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_actor_show (_tmp3_);
#line 1608 "util-app.c"
	}
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _data58_->actor;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = opacity;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_reactive (_tmp4_, _tmp5_ == ((guint) 255));
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = _data58_->actor;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_save_easing_state (_tmp6_);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _data58_->actor;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_easing_mode (_tmp7_, CLUTTER_EASE_OUT_QUAD);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = _data58_->actor;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = boxes_app_app;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = _tmp9_->duration;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_easing_duration (_tmp8_, _tmp10_);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = _data58_->actor;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = opacity;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_opacity (_tmp11_, _tmp12_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = _data58_->actor;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = clutter_actor_get_transition (_tmp13_, "opacity");
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = _g_object_ref0 (_tmp14_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	t = _tmp15_;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_signal_connect_data ((ClutterTimeline*) t, "completed", (GCallback) ___lambda130__clutter_timeline_completed, block58_data_ref (_data58_), (GClosureNotify) block58_data_unref, 0);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp16_ = _data58_->actor;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_restore_easing_state (_tmp16_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (t);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	block58_data_unref (_data58_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_ = NULL;
#line 1658 "util-app.c"
}


void boxes_actor_add (ClutterActor* actor, ClutterActor* container) {
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_;
	ClutterActor* _tmp3_;
	ClutterActor* _tmp4_;
	ClutterActor* _tmp5_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (container != NULL);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = clutter_actor_get_parent (_tmp0_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = container;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp1_ == _tmp2_) {
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1683 "util-app.c"
	}
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = actor;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_actor_remove (_tmp3_);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = container;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = actor;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_add_child (_tmp4_, _tmp5_);
#line 1695 "util-app.c"
}


void boxes_actor_remove (ClutterActor* actor) {
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_;
	ClutterActor* container;
	ClutterActor* _tmp3_;
	ClutterActor* _tmp4_;
	ClutterActor* _tmp5_;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = clutter_actor_get_parent (_tmp0_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	container = _tmp2_;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = container;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == NULL) {
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (container);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1725 "util-app.c"
	}
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = container;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = actor;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_remove_child (_tmp4_, _tmp5_);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (container);
#line 1735 "util-app.c"
}


OsinfoDevice* boxes_get_os_device_by_prop (OsinfoOs* os, const gchar* prop_name, const gchar* prop_value) {
	OsinfoDevice* result = NULL;
	OsinfoOs* _tmp0_;
	OsinfoOs* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	OsinfoDeviceList* _tmp4_ = NULL;
	OsinfoDeviceList* devices;
	OsinfoDevice* _tmp5_ = NULL;
	OsinfoDeviceList* _tmp6_;
	gint _tmp7_ = 0;
	OsinfoDevice* _tmp10_;
	OsinfoDevice* _tmp11_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_name != NULL, NULL);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_value != NULL, NULL);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = os;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0_ == NULL) {
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1764 "util-app.c"
	}
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = os;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = prop_name;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = prop_value;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = osinfo_os_get_devices_by_property (_tmp1_, _tmp2_, _tmp3_, TRUE);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	devices = _tmp4_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = devices;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = osinfo_list_get_length ((OsinfoList*) _tmp6_);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_ > 0) {
#line 1782 "util-app.c"
		OsinfoDeviceList* _tmp8_;
		OsinfoEntity* _tmp9_ = NULL;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = devices;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = osinfo_list_get_nth ((OsinfoList*) _tmp8_, 0);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, osinfo_device_get_type ()) ? ((OsinfoDevice*) _tmp9_) : NULL;
#line 1791 "util-app.c"
	} else {
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = NULL;
#line 1795 "util-app.c"
	}
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = _tmp5_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp11_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (devices);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1807 "util-app.c"
}


GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size) {
	GtkImage* result = NULL;
	GtkImage* _tmp0_;
	GtkImage* image;
	GtkImage* _tmp1_;
	gint _tmp2_;
	OsinfoOs* _tmp3_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_ref_sink (_tmp0_);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	image = _tmp0_;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = image;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = size;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_image_set_pixel_size (_tmp1_, _tmp2_);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = os;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ != NULL) {
#line 1834 "util-app.c"
		GtkImage* _tmp4_;
		OsinfoOs* _tmp5_;
		gint _tmp6_;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = image;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = os;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = size;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_fetch_os_logo (_tmp4_, _tmp5_, _tmp6_);
#line 1846 "util-app.c"
	}
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = image;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1852 "util-app.c"
}


void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size) {
	OsinfoOs* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_;
	gchar* path;
	const gchar* _tmp8_;
	GError * _inner_error_ = NULL;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (image != NULL);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (os != NULL);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = os;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_strdup (".svg");
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup (".png");
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_strdup (".jpg");
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[0] = _tmp1_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[1] = _tmp2_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[2] = _tmp3_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5__length1 = 3;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = boxes_get_logo_path (_tmp0_, _tmp5_, 3);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp7_;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = path;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp8_ == NULL) {
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1909 "util-app.c"
	}
	{
		const gchar* _tmp9_;
		gint _tmp10_;
		GdkPixbuf* _tmp11_;
		GdkPixbuf* pixbuf;
		GtkImage* _tmp12_;
		GdkPixbuf* _tmp13_;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = path;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = size;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = gdk_pixbuf_new_from_file_at_size (_tmp9_, _tmp10_, -1, &_inner_error_);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		pixbuf = _tmp11_;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_ != NULL) {
#line 1928 "util-app.c"
			goto __catch78_g_error;
		}
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = image;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = pixbuf;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_image_set_from_pixbuf (_tmp12_, _tmp13_);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pixbuf);
#line 1939 "util-app.c"
	}
	goto __finally78;
	__catch78_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp14_;
		GError* _tmp15_;
		const gchar* _tmp16_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_error_ = _inner_error_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = path;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = _error_;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_->message;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:176: Error loading logo file '%s': %s", _tmp14_, _tmp16_);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_error_);
#line 1962 "util-app.c"
	}
	__finally78:
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_inner_error_ != NULL) {
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1975 "util-app.c"
	}
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 1979 "util-app.c"
}


GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection) {
	GVirStoragePool* result = NULL;
	GVirConnection* _tmp0_;
	GVirStoragePool* _tmp1_ = NULL;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gvir_connection_find_storage_pool_by_name (_tmp0_, PACKAGE_TARNAME);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp1_;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1997 "util-app.c"
}


GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain) {
	GVirStorageVol* result = NULL;
	GVirConnection* _tmp0_;
	GVirStoragePool* _tmp1_ = NULL;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp2_;
	GVirStoragePool* _tmp3_;
	GVirDomain* _tmp4_;
	const gchar* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = boxes_get_storage_pool (_tmp0_);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	pool = _tmp1_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pool;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pool);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2031 "util-app.c"
	}
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = pool;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = domain;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = gvir_storage_pool_get_volume (_tmp3_, _tmp5_);
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp6_;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (pool);
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 2047 "util-app.c"
}


gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1) {
	gchar* result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	OsinfoOs* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_;
	gchar* path;
	const gchar* _tmp10_;
	GFile* _tmp11_ = NULL;
	GFile* file;
	GFile* _tmp12_;
	gboolean _tmp13_ = FALSE;
	GFile* _tmp24_;
	gboolean _tmp25_ = FALSE;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = extensions;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0__length1 = extensions_length1;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0__length1 == 0) {
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2085 "util-app.c"
	}
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = os;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp1_);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = extensions;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4__length1 = extensions_length1;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_[0];
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = g_strconcat (_tmp3_, _tmp5_, NULL);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = boxes_get_pixmap (_tmp7_);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp7_);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp9_;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = path;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = g_file_new_for_path (_tmp10_);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	file = _tmp11_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = file;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = g_file_query_exists (_tmp12_, NULL);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_tmp13_) {
#line 2123 "util-app.c"
		OsinfoOs* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		gchar** _tmp17_;
		gint _tmp17__length1;
		const gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_;
		GFile* _tmp23_ = NULL;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = os;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = osinfo_os_get_distro (_tmp14_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17_ = extensions;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17__length1 = extensions_length1;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp18_ = _tmp17_[0];
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp19_ = g_strconcat (_tmp16_, _tmp18_, NULL);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp20_ = _tmp19_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = boxes_get_pixmap (_tmp20_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp21_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp20_);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp22_ = path;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp23_ = g_file_new_for_path (_tmp22_);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp23_;
#line 2167 "util-app.c"
	}
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp24_ = file;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp25_ = g_file_query_exists (_tmp24_, NULL);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp25_) {
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = path;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2181 "util-app.c"
	} else {
		OsinfoOs* _tmp26_;
		gchar** _tmp27_;
		gint _tmp27__length1;
		gchar** _tmp28_;
		gint _tmp28__length1;
		gchar* _tmp29_ = NULL;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = os;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = extensions;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27__length1 = extensions_length1;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = extensions;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28__length1 = extensions_length1;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp29_ = boxes_get_logo_path (_tmp26_, _tmp27_ + 1, _tmp28__length1 - 1);
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp29_;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2209 "util-app.c"
	}
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (file);
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 2215 "util-app.c"
}


static void boxes_check_selinux_context_default_data_free (gpointer _data) {
	BoxesCheckSelinuxContextDefaultData* _data_;
	_data_ = _data;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckSelinuxContextDefaultData, _data_);
#line 2224 "util-app.c"
}


void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckSelinuxContextDefaultData);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_selinux_context_default);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_selinux_context_default_data_free);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 2238 "util-app.c"
}


gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 2251 "util-app.c"
	} else {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 2255 "util-app.c"
	}
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2263 "util-app.c"
}


static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 2277 "util-app.c"
}


static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_) {
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2286 "util-app.c"
		goto _state_0;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2290 "util-app.c"
		goto _state_1;
		default:
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2295 "util-app.c"
	}
	_state_0:
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 2304 "util-app.c"
	{
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("restorecon");
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("-nrv");
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = boxes_get_user_pkgconfig (NULL);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = boxes_get_user_pkgdata (NULL);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = boxes_get_user_pkgcache (NULL);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = g_new0 (gchar*, 5 + 1);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[0] = _data_->_tmp1_;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[1] = _data_->_tmp2_;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[2] = _data_->_tmp3_;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[3] = _data_->_tmp4_;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[4] = _data_->_tmp5_;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp6_;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 5;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->argv;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7__length1 = _data_->argv_length1;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp7_, _data_->_tmp7__length1, NULL, boxes_check_selinux_context_default_ready, _data_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2354 "util-app.c"
		_state_1:
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp8_, NULL, &_data_->_inner_error_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp8_;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 2370 "util-app.c"
				goto __catch79_g_spawn_error_noexec;
			}
			goto __catch79_g_error;
		}
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->standard_output;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = strlen (_data_->_tmp9_);
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_tmp11_ == 0) {
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->result = TRUE;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2393 "util-app.c"
			} else {
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2397 "util-app.c"
			}
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 2403 "util-app.c"
		}
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->argv;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12__length1 = _data_->argv_length1;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_strdup ("-r");
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp12_[1]);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_[1] = _data_->_tmp13_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp12_[1];
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = NULL;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = _ ("Your SELinux context looks incorrect, you can try to fix it by running" \
":\n" \
"%s");
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = _data_->argv;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16__length1 = _data_->argv_length1;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = NULL;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = g_strjoinv (" ", _data_->_tmp16_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = _data_->_tmp17_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = NULL;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = g_strdup_printf (_data_->_tmp15_, _data_->_tmp18_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp19_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp18_);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2451 "util-app.c"
		} else {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2455 "util-app.c"
		}
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2461 "util-app.c"
	}
	goto __finally79;
	__catch79_g_spawn_error_noexec:
	{
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = NULL;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = _ ("SELinux not installed?");
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp21_;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = TRUE;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2488 "util-app.c"
		} else {
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2492 "util-app.c"
		}
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2498 "util-app.c"
	}
	goto __finally79;
	__catch79_g_error:
	{
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _data_->_vala1__error_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:237: %s", _data_->_tmp23_);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 2515 "util-app.c"
	}
	__finally79:
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2526 "util-app.c"
	}
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2534 "util-app.c"
	} else {
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2538 "util-app.c"
	}
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2548 "util-app.c"
	} else {
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2552 "util-app.c"
	}
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2558 "util-app.c"
}


static void boxes_check_libvirt_kvm_data_free (gpointer _data) {
	BoxesCheckLibvirtKvmData* _data_;
	_data_ = _data;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckLibvirtKvmData, _data_);
#line 2567 "util-app.c"
}


void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckLibvirtKvmData);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_libvirt_kvm);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_libvirt_kvm_data_free);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 2581 "util-app.c"
}


gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckLibvirtKvmData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2594 "util-app.c"
}


static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 2608 "util-app.c"
}


static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_) {
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2617 "util-app.c"
		goto _state_0;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2621 "util-app.c"
		goto _state_1;
		default:
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2626 "util-app.c"
	}
	_state_0:
	{
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = g_strdup ("virsh");
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("capabilities");
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[0] = _data_->_tmp0_;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[1] = _data_->_tmp1_;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp2_;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 2;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->argv;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3__length1 = _data_->argv_length1;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp3_, _data_->_tmp3__length1, NULL, boxes_check_libvirt_kvm_ready, _data_);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2660 "util-app.c"
		_state_1:
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp4_, NULL, &_data_->_inner_error_);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp4_;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 2676 "util-app.c"
				goto __catch80_g_spawn_error_noexec;
			}
			goto __catch80_g_error;
		}
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->standard_output;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = boxes_extract_xpath (_data_->_tmp5_, "string(/capabilities/guest[os_type='hvm']/arch/domain[@type='kvm']/emu" \
"lator)", FALSE, &_data_->_inner_error_);
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->kvm = _data_->_tmp6_;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 2697 "util-app.c"
				goto __catch80_g_spawn_error_noexec;
			}
			goto __catch80_g_error;
		}
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->kvm;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = strlen (_data_->_tmp7_);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = _data_->_tmp9_ != 0;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->kvm);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2720 "util-app.c"
		} else {
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2724 "util-app.c"
		}
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2730 "util-app.c"
	}
	goto __finally80;
	__catch80_g_spawn_error_noexec:
	{
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("util-app.vala:254: libvirt is not installed correctly");
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 2743 "util-app.c"
	}
	goto __finally80;
	__catch80_g_error:
	{
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_vala1__error_;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_->message;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:256: %s", _data_->_tmp11_);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 2760 "util-app.c"
	}
	__finally80:
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2771 "util-app.c"
	}
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2779 "util-app.c"
	} else {
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2783 "util-app.c"
	}
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2793 "util-app.c"
	} else {
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2797 "util-app.c"
	}
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2803 "util-app.c"
}


static void boxes_check_cpu_vt_capability_data_free (gpointer _data) {
	BoxesCheckCpuVtCapabilityData* _data_;
	_data_ = _data;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckCpuVtCapabilityData, _data_);
#line 2812 "util-app.c"
}


void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckCpuVtCapabilityData);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_cpu_vt_capability);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_cpu_vt_capability_data_free);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 2826 "util-app.c"
}


gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckCpuVtCapabilityData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2839 "util-app.c"
}


static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 2853 "util-app.c"
}


static inline GRegex* _thread_safe_regex_init (GRegex** re, const gchar * pattern, GRegexMatchFlags match_options) {
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_once_init_enter ((volatile gsize*) re)) {
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		GRegex* val = g_regex_new (pattern, match_options, 0, NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_once_init_leave ((volatile gsize*) re, (gsize) val);
#line 2864 "util-app.c"
	}
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return *re;
#line 2868 "util-app.c"
}


static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_) {
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2877 "util-app.c"
		goto _state_0;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2881 "util-app.c"
		goto _state_1;
		default:
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2886 "util-app.c"
	}
	_state_0:
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/cpuinfo");
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 2897 "util-app.c"
	{
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->file;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_file_read (_data_->_tmp1_, NULL, &_data_->_inner_error_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 2909 "util-app.c"
			goto __catch81_g_error;
		}
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp4_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp6_;
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = _data_->stream;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp7_, G_PRIORITY_DEFAULT, NULL, boxes_check_cpu_vt_capability_ready, _data_);
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 2934 "util-app.c"
			_state_1:
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = g_data_input_stream_read_line_finish (_data_->_tmp7_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = _data_->_tmp8_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_inner_error_ != NULL) {
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 2948 "util-app.c"
				goto __catch81_g_error;
			}
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp9_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp10_ != NULL)) {
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 2961 "util-app.c"
			}
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = _data_->line;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_0, "^flags.*(vmx|svm)", 0), _data_->_tmp11_, 0, NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp12_;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp13_ = _data_->_result_;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp13_) {
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 2977 "util-app.c"
			}
		}
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 2984 "util-app.c"
	}
	goto __finally81;
	__catch81_g_error:
	{
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_error_->message;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error ("util-app.vala:275: %s", _data_->_tmp14_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 2999 "util-app.c"
	}
	__finally81:
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3012 "util-app.c"
	}
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_cpu_vt_capability: ", _data_->_tmp17_, NULL);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:278: %s", _data_->_tmp19_);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3040 "util-app.c"
	} else {
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3044 "util-app.c"
	}
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3056 "util-app.c"
	} else {
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3060 "util-app.c"
	}
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3066 "util-app.c"
}


static void boxes_check_module_kvm_loaded_data_free (gpointer _data) {
	BoxesCheckModuleKvmLoadedData* _data_;
	_data_ = _data;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckModuleKvmLoadedData, _data_);
#line 3075 "util-app.c"
}


void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckModuleKvmLoadedData);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_module_kvm_loaded);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_module_kvm_loaded_data_free);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3089 "util-app.c"
}


gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckModuleKvmLoadedData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3102 "util-app.c"
}


static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3116 "util-app.c"
}


static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_) {
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3125 "util-app.c"
		goto _state_0;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3129 "util-app.c"
		goto _state_1;
		default:
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3134 "util-app.c"
	}
	_state_0:
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/modules");
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 3145 "util-app.c"
	{
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->file;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_file_read (_data_->_tmp1_, NULL, &_data_->_inner_error_);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 3157 "util-app.c"
			goto __catch82_g_error;
		}
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp4_);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp6_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = _data_->stream;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp7_, G_PRIORITY_DEFAULT, NULL, boxes_check_module_kvm_loaded_ready, _data_);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 3182 "util-app.c"
			_state_1:
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = g_data_input_stream_read_line_finish (_data_->_tmp7_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = _data_->_tmp8_;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_inner_error_ != NULL) {
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 3196 "util-app.c"
				goto __catch82_g_error;
			}
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp9_;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp10_ != NULL)) {
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3209 "util-app.c"
			}
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = _data_->line;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_1, "^(kvm_intel|kvm_amd)", 0), _data_->_tmp11_, 0, NULL);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp12_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp13_ = _data_->_result_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp13_) {
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3225 "util-app.c"
			}
		}
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 3232 "util-app.c"
	}
	goto __finally82;
	__catch82_g_error:
	{
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_error_->message;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error ("util-app.vala:295: %s", _data_->_tmp14_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3247 "util-app.c"
	}
	__finally82:
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3260 "util-app.c"
	}
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_module_kvm_loaded: ", _data_->_tmp17_, NULL);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:298: %s", _data_->_tmp19_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3288 "util-app.c"
	} else {
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3292 "util-app.c"
	}
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3304 "util-app.c"
	} else {
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3308 "util-app.c"
	}
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3314 "util-app.c"
}


static void boxes_check_storage_pool_data_free (gpointer _data) {
	BoxesCheckStoragePoolData* _data_;
	_data_ = _data;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckStoragePoolData, _data_);
#line 3323 "util-app.c"
}


void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckStoragePoolData);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_storage_pool);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_storage_pool_data_free);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_storage_pool_co (_data_);
#line 3337 "util-app.c"
}


gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckStoragePoolData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 3350 "util-app.c"
	} else {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 3354 "util-app.c"
	}
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3362 "util-app.c"
}


static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_storage_pool_co (_data_);
#line 3376 "util-app.c"
}


static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_) {
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3385 "util-app.c"
		goto _state_0;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3389 "util-app.c"
		goto _state_1;
		default:
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3394 "util-app.c"
	}
	_state_0:
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 3403 "util-app.c"
	{
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("virsh");
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("pool-dumpxml");
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_strdup (PACKAGE_TARNAME);
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[0] = _data_->_tmp1_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[1] = _data_->_tmp2_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[2] = _data_->_tmp3_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp4_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 3;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->argv;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5__length1 = _data_->argv_length1;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp5_, _data_->_tmp5__length1, NULL, boxes_check_storage_pool_ready, _data_);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3439 "util-app.c"
		_state_1:
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp6_, NULL, &_data_->_inner_error_);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp6_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 3453 "util-app.c"
			goto __catch83_g_error;
		}
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->standard_output;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = boxes_extract_xpath (_data_->_tmp7_, "string(/pool[@type='dir']/target/path)", FALSE, &_data_->_inner_error_);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 3470 "util-app.c"
			goto __catch83_g_error;
		}
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->pool_path = _data_->_tmp9_;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 3481 "util-app.c"
	}
	goto __finally83;
	__catch83_g_error:
	{
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_error_;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_->message;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:313: %s", _data_->_tmp11_);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _ ("Could not get 'gnome-boxes' storage pool information from libvirt. Mak" \
"e sure 'virsh -c qemu:///session pool-dumpxml gnome-boxes' is working.");
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_strdup (_data_->_tmp12_);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp13_;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3516 "util-app.c"
		} else {
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3520 "util-app.c"
		}
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3526 "util-app.c"
	}
	__finally83:
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3539 "util-app.c"
	}
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp14_ = _data_->pool_path;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = g_file_test (_data_->_tmp14_, G_FILE_TEST_EXISTS);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp15_) {
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = NULL;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but this director" \
"y does not exist");
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = _data_->pool_path;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = NULL;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = g_strdup_printf (_data_->_tmp16_, _data_->_tmp17_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp18_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3571 "util-app.c"
		} else {
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3575 "util-app.c"
		}
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3581 "util-app.c"
	}
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->pool_path;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = FALSE;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = g_file_test (_data_->_tmp19_, G_FILE_TEST_IS_DIR);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp20_) {
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = NULL;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not a dire" \
"ctory");
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _data_->pool_path;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = NULL;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = g_strdup_printf (_data_->_tmp21_, _data_->_tmp22_);
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp23_;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3613 "util-app.c"
		} else {
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3617 "util-app.c"
		}
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3623 "util-app.c"
	}
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp24_ = _data_->pool_path;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = 0;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = access (_data_->_tmp24_, (R_OK | W_OK) | X_OK);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_tmp25_ != 0) {
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp26_ = NULL;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp26_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not user-r" \
"eadable/writable");
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp27_ = _data_->pool_path;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = NULL;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = g_strdup_printf (_data_->_tmp26_, _data_->_tmp27_);
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp28_;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3655 "util-app.c"
		} else {
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3659 "util-app.c"
		}
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3665 "util-app.c"
	}
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = TRUE;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3675 "util-app.c"
	} else {
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3679 "util-app.c"
	}
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3691 "util-app.c"
	} else {
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3695 "util-app.c"
	}
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3701 "util-app.c"
}


static guint8* _vala_array_dup5 (guint8* self, int length) {
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return g_memdup (self, length * sizeof (guint8));
#line 3708 "util-app.c"
}


GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf) {
	GdkPixbuf* result = NULL;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const guint8 ALPHA_TRESHOLD = (guint8) 50;
#line 3716 "util-app.c"
	gboolean _tmp0_ = FALSE;
	GdkPixbuf* _tmp1_;
	gint _tmp2_ = 0;
	gboolean _tmp5_;
	GdkPixbuf* _tmp6_;
	GdkPixbuf* _tmp7_;
	gint _tmp8_ = 0;
	gint width;
	GdkPixbuf* _tmp9_;
	gint _tmp10_ = 0;
	gint height;
	GdkPixbuf* _tmp11_;
	gint _tmp12_ = 0;
	gint rowstride;
	GdkPixbuf* _tmp13_;
	guint8* _tmp14_ = NULL;
	guint8* orig_pixels;
	gint orig_pixels_length1;
	gint _orig_pixels_size_;
	gint _tmp15_;
	gint _tmp16_;
	guint8* _tmp17_ = NULL;
	guint8* pixels;
	gint pixels_length1;
	gint _pixels_size_;
	guint8* _tmp65_;
	gint _tmp65__length1;
	guint8* _tmp66_;
	gint _tmp66__length1;
	GdkPixbuf* _tmp67_;
	GdkColorspace _tmp68_ = 0;
	gint _tmp69_;
	gint _tmp70_;
	gint _tmp71_;
	GdkPixbuf* _tmp72_;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = pixbuf;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = gdk_pixbuf_get_n_channels (_tmp1_);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == 4) {
#line 3760 "util-app.c"
		GdkPixbuf* _tmp3_;
		gint _tmp4_ = 0;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = pixbuf;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = gdk_pixbuf_get_bits_per_sample (_tmp3_);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp4_ == 8;
#line 3769 "util-app.c"
	} else {
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = FALSE;
#line 3773 "util-app.c"
	}
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp0_;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = pixbuf;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (_tmp5_, _tmp6_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = pixbuf;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = gdk_pixbuf_get_width (_tmp7_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	width = _tmp8_;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = pixbuf;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = gdk_pixbuf_get_height (_tmp9_);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	height = _tmp10_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = pixbuf;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = gdk_pixbuf_get_rowstride (_tmp11_);
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	rowstride = _tmp12_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = pixbuf;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = gdk_pixbuf_get_pixels (_tmp13_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels = _tmp14_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels_length1 = -1;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_orig_pixels_size_ = orig_pixels_length1;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = rowstride;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp16_ = height;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17_ = g_new0 (guint8, _tmp15_ * _tmp16_);
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = _tmp17_;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels_length1 = _tmp15_ * _tmp16_;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_pixels_size_ = pixels_length1;
#line 3821 "util-app.c"
	{
		gint i;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		i = 0;
#line 3826 "util-app.c"
		{
			gboolean _tmp18_;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = TRUE;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			while (TRUE) {
#line 3833 "util-app.c"
				gboolean _tmp19_;
				gint _tmp21_;
				gint _tmp22_;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = _tmp18_;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!_tmp19_) {
#line 3841 "util-app.c"
					gint _tmp20_;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp20_ = i;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					i = _tmp20_ + 1;
#line 3847 "util-app.c"
				}
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp18_ = FALSE;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp21_ = i;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp22_ = height;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!(_tmp21_ < _tmp22_)) {
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					break;
#line 3859 "util-app.c"
				}
				{
					gint j;
					gint k;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					j = 0;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					k = 0;
#line 3868 "util-app.c"
					{
						gboolean _tmp23_;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
						_tmp23_ = TRUE;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
						while (TRUE) {
#line 3875 "util-app.c"
							gboolean _tmp24_;
							gint _tmp27_;
							gint _tmp28_;
							gint _tmp29_;
							gint _tmp30_;
							gint _tmp31_;
							gint orig_index;
							gint _tmp32_;
							gint _tmp33_;
							gint _tmp34_;
							gint index;
							guint8* _tmp35_;
							gint _tmp35__length1;
							gint _tmp36_;
							guint8 _tmp37_;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp24_ = _tmp23_;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!_tmp24_) {
#line 3895 "util-app.c"
								gint _tmp25_;
								gint _tmp26_;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp25_ = j;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								j = _tmp25_ + 4;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp26_ = k;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								k = _tmp26_ + 3;
#line 3906 "util-app.c"
							}
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp23_ = FALSE;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp27_ = j;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp28_ = width;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!(_tmp27_ < (_tmp28_ * 4))) {
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								break;
#line 3918 "util-app.c"
							}
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp29_ = rowstride;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp30_ = i;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp31_ = j;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							orig_index = (_tmp29_ * _tmp30_) + _tmp31_;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp32_ = rowstride;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp33_ = i;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp34_ = k;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							index = (_tmp32_ * _tmp33_) + _tmp34_;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp35_ = orig_pixels;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp35__length1 = orig_pixels_length1;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp36_ = orig_index;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp37_ = _tmp35_[_tmp36_ + 3];
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (_tmp37_ < ALPHA_TRESHOLD) {
#line 3946 "util-app.c"
								guint8* _tmp38_;
								gint _tmp38__length1;
								gint _tmp39_;
								guint8 _tmp40_;
								guint8* _tmp41_;
								gint _tmp41__length1;
								gint _tmp42_;
								guint8 _tmp43_;
								guint8* _tmp44_;
								gint _tmp44__length1;
								gint _tmp45_;
								guint8 _tmp46_;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_ = pixels;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38__length1 = pixels_length1;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp39_ = index;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_[_tmp39_] = (guint8) 0xFF;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp40_ = _tmp38_[_tmp39_];
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_ = pixels;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41__length1 = pixels_length1;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp42_ = index;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_[_tmp42_ + 1] = (guint8) 0xFF;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp43_ = _tmp41_[_tmp42_ + 1];
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_ = pixels;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44__length1 = pixels_length1;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp45_ = index;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_[_tmp45_ + 2] = (guint8) 0xFF;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp46_ = _tmp44_[_tmp45_ + 2];
#line 3989 "util-app.c"
							} else {
								guint8* _tmp47_;
								gint _tmp47__length1;
								gint _tmp48_;
								guint8* _tmp49_;
								gint _tmp49__length1;
								gint _tmp50_;
								guint8 _tmp51_;
								guint8 _tmp52_;
								guint8* _tmp53_;
								gint _tmp53__length1;
								gint _tmp54_;
								guint8* _tmp55_;
								gint _tmp55__length1;
								gint _tmp56_;
								guint8 _tmp57_;
								guint8 _tmp58_;
								guint8* _tmp59_;
								gint _tmp59__length1;
								gint _tmp60_;
								guint8* _tmp61_;
								gint _tmp61__length1;
								gint _tmp62_;
								guint8 _tmp63_;
								guint8 _tmp64_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47_ = pixels;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47__length1 = pixels_length1;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp48_ = index;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp49_ = orig_pixels;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp49__length1 = orig_pixels_length1;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50_ = orig_index;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp51_ = _tmp49_[_tmp50_];
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47_[_tmp48_] = _tmp51_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp52_ = _tmp47_[_tmp48_];
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53_ = pixels;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53__length1 = pixels_length1;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp54_ = index;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp55_ = orig_pixels;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp55__length1 = orig_pixels_length1;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56_ = orig_index;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp57_ = _tmp55_[_tmp56_ + 1];
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53_[_tmp54_ + 1] = _tmp57_;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp58_ = _tmp53_[_tmp54_ + 1];
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59_ = pixels;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59__length1 = pixels_length1;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp60_ = index;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp61_ = orig_pixels;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp61__length1 = orig_pixels_length1;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp62_ = orig_index;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp63_ = _tmp61_[_tmp62_ + 2];
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59_[_tmp60_ + 2] = _tmp63_;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp64_ = _tmp59_[_tmp60_ + 2];
#line 4069 "util-app.c"
							}
						}
					}
				}
			}
		}
	}
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp65_ = pixels;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp65__length1 = pixels_length1;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp66_ = (_tmp65_ != NULL) ? _vala_array_dup5 (_tmp65_, _tmp65__length1) : ((gpointer) _tmp65_);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp66__length1 = _tmp65__length1;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp67_ = pixbuf;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp68_ = gdk_pixbuf_get_colorspace (_tmp67_);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp69_ = width;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp70_ = height;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp71_ = rowstride;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp72_ = gdk_pixbuf_new_from_data (_tmp66_, _tmp68_, FALSE, 8, _tmp69_, _tmp70_, _tmp71_, (GdkPixbufDestroyNotify) NULL, NULL);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp72_;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = (g_free (pixels), NULL);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4103 "util-app.c"
}


static Block59Data* block59_data_ref (Block59Data* _data59_) {
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data59_->_ref_count_);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data59_;
#line 4112 "util-app.c"
}


static void block59_data_unref (void * _userdata_) {
	Block59Data* _data59_;
	_data59_ = (Block59Data*) _userdata_;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data59_->_ref_count_)) {
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data59_->widget);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block59Data, _data59_);
#line 4125 "util-app.c"
	}
}


static gboolean __lambda166_ (Block59Data* _data59_, cairo_t* cr) {
	gboolean result = FALSE;
	GtkWidget* _tmp0_;
	GtkStyleContext* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_;
	GtkStyleContext* context;
	GtkAllocation allocation = {0};
	GtkWidget* _tmp3_;
	GtkAllocation _tmp4_ = {0};
	cairo_t* _tmp5_;
	GtkAllocation _tmp6_;
	gint _tmp7_;
	GtkAllocation _tmp8_;
	gint _tmp9_;
	cairo_t* _tmp10_;
	GtkAllocation _tmp11_;
	gint _tmp12_;
	GtkAllocation _tmp13_;
	gint _tmp14_;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _data59_->widget;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_get_style_context (_tmp0_);
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	context = _tmp2_;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _data59_->widget;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_widget_get_allocation (_tmp3_, &_tmp4_);
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	allocation = _tmp4_;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = cr;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = allocation;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_.width;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = allocation;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_.height;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_background (context, _tmp5_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp7_, (gdouble) _tmp9_);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = cr;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = allocation;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = _tmp11_.width;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = allocation;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = _tmp13_.height;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_frame (context, _tmp10_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp12_, (gdouble) _tmp14_);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (context);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4195 "util-app.c"
}


static gboolean ___lambda166__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda166_ (self, cr);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4204 "util-app.c"
}


void boxes_draw_as_css_box (GtkWidget* widget) {
	Block59Data* _data59_;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (widget != NULL);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data59_ = g_slice_new0 (Block59Data);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data59_->_ref_count_ = 1;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = widget;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data59_->widget);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data59_->widget = _tmp1_;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data59_->widget;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_signal_connect_data (_tmp2_, "draw", (GCallback) ___lambda166__gtk_widget_draw, block59_data_ref (_data59_), (GClosureNotify) block59_data_unref, 0);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	block59_data_unref (_data59_);
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data59_ = NULL;
#line 4235 "util-app.c"
}


static void boxes_copy_file_data_free (gpointer _data) {
	BoxesCopyFileData* _data_;
	_data_ = _data;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->src_file);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->dest_file);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCopyFileData, _data_);
#line 4250 "util-app.c"
}


void boxes_copy_file (GFile* src_file, GFile* dest_file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCopyFileData* _data_;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GCancellable* _tmp4_;
	GCancellable* _tmp5_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCopyFileData);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_copy_file);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_copy_file_data_free);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = src_file;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->src_file);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->src_file = _tmp1_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = dest_file;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->dest_file);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->dest_file = _tmp3_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = cancellable;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancellable = _tmp5_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_copy_file_co (_data_);
#line 4294 "util-app.c"
}


void boxes_copy_file_finish (GAsyncResult* _res_, GError** error) {
	BoxesCopyFileData* _data_;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 4304 "util-app.c"
	}
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4308 "util-app.c"
}


static void boxes_copy_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCopyFileData* _data_;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_copy_file_co (_data_);
#line 4322 "util-app.c"
}


static gboolean boxes_copy_file_co (BoxesCopyFileData* _data_) {
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 4331 "util-app.c"
		goto _state_0;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 4335 "util-app.c"
		goto _state_1;
		default:
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 4340 "util-app.c"
	}
	_state_0:
	{
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = _data_->src_file;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_file_get_path (_data_->_tmp0_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->dest_file;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_file_get_path (_data_->_tmp3_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:391: Copying '%s' to '%s'..", _data_->_tmp2_, _data_->_tmp5_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp5_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp2_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->src_file;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->dest_file;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = _data_->cancellable;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_copy_async (_data_->_tmp6_, _data_->_tmp7_, 0, G_PRIORITY_DEFAULT, _data_->_tmp8_, NULL, NULL, boxes_copy_file_ready, _data_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4378 "util-app.c"
		_state_1:
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_copy_finish (_data_->_tmp6_, _data_->_res_, &_data_->_inner_error_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
#line 4386 "util-app.c"
				goto __catch84_g_io_error_exists;
			}
			goto __finally84;
		}
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->src_file;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = g_file_get_path (_data_->_tmp9_);
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->dest_file;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_file_get_path (_data_->_tmp12_);
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp13_;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:393: Copied '%s' to '%s'.", _data_->_tmp11_, _data_->_tmp14_);
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp14_);
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp11_);
#line 4413 "util-app.c"
	}
	goto __finally84;
	__catch84_g_io_error_exists:
	{
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 4424 "util-app.c"
	}
	__finally84:
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4437 "util-app.c"
		} else {
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4441 "util-app.c"
		}
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4447 "util-app.c"
	}
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4453 "util-app.c"
	} else {
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4457 "util-app.c"
	}
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 4463 "util-app.c"
}


GType boxes_cpu_arch_compatibity_get_type (void) {
	static volatile gsize boxes_cpu_arch_compatibity_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_cpu_arch_compatibity_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE, "BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE", "incompatible"}, {BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL, "BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL", "identical"}, {BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE, "BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE", "compatible"}, {BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE_DIFF_WORDSIZE, "BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE_DIFF_WORDSIZE", "compatible-diff-wordsize"}, {0, NULL, NULL}};
		GType boxes_cpu_arch_compatibity_type_id;
		boxes_cpu_arch_compatibity_type_id = g_enum_register_static ("BoxesCPUArchCompatibity", values);
		g_once_init_leave (&boxes_cpu_arch_compatibity_type_id__volatile, boxes_cpu_arch_compatibity_type_id);
	}
	return boxes_cpu_arch_compatibity_type_id__volatile;
}


BoxesCPUArchCompatibity boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2) {
	BoxesCPUArchCompatibity result = 0;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label0 = 0;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label1 = 0;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label2 = 0;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label3 = 0;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label4 = 0;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch1 != NULL, 0);
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch2 != NULL, 0);
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = arch2;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("i386")))) {
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4508 "util-app.c"
			default:
			{
				const gchar* _tmp4_;
				const gchar* _tmp5_;
				GQuark _tmp7_ = 0U;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label0 = 0;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label1 = 0;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label2 = 0;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label3 = 0;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label4 = 0;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp4_ = arch1;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp5_ = _tmp4_;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp7_ = (NULL == _tmp5_) ? 0 : g_quark_from_string (_tmp5_);
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp7_ == ((0 != _tmp6_label0) ? _tmp6_label0 : (_tmp6_label0 = g_quark_from_static_string ("i386")))) {
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4534 "util-app.c"
						default:
						{
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4541 "util-app.c"
						}
					}
				} else if (((_tmp7_ == ((0 != _tmp6_label1) ? _tmp6_label1 : (_tmp6_label1 = g_quark_from_static_string ("i486")))) || (_tmp7_ == ((0 != _tmp6_label2) ? _tmp6_label2 : (_tmp6_label2 = g_quark_from_static_string ("i586"))))) || (_tmp7_ == ((0 != _tmp6_label3) ? _tmp6_label3 : (_tmp6_label3 = g_quark_from_static_string ("i686"))))) {
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4547 "util-app.c"
						default:
						{
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4554 "util-app.c"
						}
					}
				} else if (_tmp7_ == ((0 != _tmp6_label4) ? _tmp6_label4 : (_tmp6_label4 = g_quark_from_static_string ("x86_64")))) {
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4560 "util-app.c"
						default:
						{
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE_DIFF_WORDSIZE;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4567 "util-app.c"
						}
					}
				} else {
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4573 "util-app.c"
						default:
						{
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4580 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("i486")))) {
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4589 "util-app.c"
			default:
			{
				const gchar* _tmp8_;
				const gchar* _tmp9_;
				GQuark _tmp11_ = 0U;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label0 = 0;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label1 = 0;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label2 = 0;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label3 = 0;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp8_ = arch1;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp9_ = _tmp8_;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp11_ = (NULL == _tmp9_) ? 0 : g_quark_from_string (_tmp9_);
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp11_ == ((0 != _tmp10_label0) ? _tmp10_label0 : (_tmp10_label0 = g_quark_from_static_string ("i486")))) {
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4613 "util-app.c"
						default:
						{
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4620 "util-app.c"
						}
					}
				} else if ((_tmp11_ == ((0 != _tmp10_label1) ? _tmp10_label1 : (_tmp10_label1 = g_quark_from_static_string ("i586")))) || (_tmp11_ == ((0 != _tmp10_label2) ? _tmp10_label2 : (_tmp10_label2 = g_quark_from_static_string ("i686"))))) {
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4626 "util-app.c"
						default:
						{
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4633 "util-app.c"
						}
					}
				} else if (_tmp11_ == ((0 != _tmp10_label3) ? _tmp10_label3 : (_tmp10_label3 = g_quark_from_static_string ("x86_64")))) {
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4639 "util-app.c"
						default:
						{
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE_DIFF_WORDSIZE;
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4646 "util-app.c"
						}
					}
				} else {
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4652 "util-app.c"
						default:
						{
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE;
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4659 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("i586")))) {
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4668 "util-app.c"
			default:
			{
				const gchar* _tmp12_;
				const gchar* _tmp13_;
				GQuark _tmp15_ = 0U;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label0 = 0;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label1 = 0;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label2 = 0;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp12_ = arch1;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp13_ = _tmp12_;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp15_ = (NULL == _tmp13_) ? 0 : g_quark_from_string (_tmp13_);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp15_ == ((0 != _tmp14_label0) ? _tmp14_label0 : (_tmp14_label0 = g_quark_from_static_string ("i586")))) {
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4690 "util-app.c"
						default:
						{
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL;
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4697 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label1) ? _tmp14_label1 : (_tmp14_label1 = g_quark_from_static_string ("i686")))) {
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4703 "util-app.c"
						default:
						{
#line 439 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE;
#line 439 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4710 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label2) ? _tmp14_label2 : (_tmp14_label2 = g_quark_from_static_string ("x86_64")))) {
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4716 "util-app.c"
						default:
						{
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE_DIFF_WORDSIZE;
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4723 "util-app.c"
						}
					}
				} else {
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4729 "util-app.c"
						default:
						{
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE;
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4736 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("i686")))) {
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4745 "util-app.c"
			default:
			{
				const gchar* _tmp16_;
				const gchar* _tmp17_;
				GQuark _tmp19_ = 0U;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label0 = 0;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label1 = 0;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp16_ = arch1;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp17_ = _tmp16_;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = (NULL == _tmp17_) ? 0 : g_quark_from_string (_tmp17_);
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp19_ == ((0 != _tmp18_label0) ? _tmp18_label0 : (_tmp18_label0 = g_quark_from_static_string ("i686")))) {
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4765 "util-app.c"
						default:
						{
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4772 "util-app.c"
						}
					}
				} else if (_tmp19_ == ((0 != _tmp18_label1) ? _tmp18_label1 : (_tmp18_label1 = g_quark_from_static_string ("x86_64")))) {
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4778 "util-app.c"
						default:
						{
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE_DIFF_WORDSIZE;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4785 "util-app.c"
						}
					}
				} else {
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4791 "util-app.c"
						default:
						{
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE;
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4798 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string ("x86_64")))) {
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4807 "util-app.c"
			default:
			{
				const gchar* _tmp20_;
				const gchar* _tmp21_;
				GQuark _tmp23_ = 0U;
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp22_label0 = 0;
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp20_ = arch1;
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp21_ = _tmp20_;
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp23_ = (NULL == _tmp21_) ? 0 : g_quark_from_string (_tmp21_);
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp23_ == ((0 != _tmp22_label0) ? _tmp22_label0 : (_tmp22_label0 = g_quark_from_static_string ("x86_64")))) {
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4825 "util-app.c"
						default:
						{
#line 457 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL;
#line 457 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4832 "util-app.c"
						}
					}
				} else {
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4838 "util-app.c"
						default:
						{
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE;
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4845 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4854 "util-app.c"
			default:
			{
#line 462 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				result = BOXES_CPU_ARCH_COMPATIBITY_COMPATIBLE;
#line 462 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				return result;
#line 4861 "util-app.c"
			}
		}
	} else {
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4867 "util-app.c"
			default:
			{
				const gchar* _tmp24_;
				const gchar* _tmp25_;
				GQuark _tmp27_ = 0U;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp24_ = arch1;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp25_ = _tmp24_;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp27_ = (NULL == _tmp25_) ? 0 : g_quark_from_string (_tmp25_);
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp27_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4883 "util-app.c"
						default:
						{
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_IDENTICAL;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4890 "util-app.c"
						}
					}
				} else {
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4896 "util-app.c"
						default:
						{
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBITY_INCOMPATIBLE;
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4903 "util-app.c"
						}
					}
				}
			}
		}
	}
}


gchar* boxes_uuid_generate (void) {
	gchar* result = NULL;
	guchar* _tmp0_ = NULL;
	guchar* udn;
	gint udn_length1;
	gint _udn_size_;
	guchar* _tmp1_ = NULL;
	guchar* id;
	gint id_length1;
	gint _id_size_;
	gchar* _tmp2_;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_new0 (guchar, 50);
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = _tmp0_;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn_length1 = 50;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_udn_size_ = udn_length1;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_new0 (guchar, 16);
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = _tmp1_;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	id_length1 = 16;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_id_size_ = id_length1;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_generate (id);
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_unparse (id, udn);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup ((const gchar*) udn);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp2_;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (g_free (id), NULL);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = (g_free (udn), NULL);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4954 "util-app.c"
}


GIcon* boxes_create_symbolic_emblem (const gchar* name) {
	GIcon* result = NULL;
	const gchar* _tmp0_;
	GIcon* _tmp1_ = NULL;
	GIcon* pix;
	GIcon* _tmp2_;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = name;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gd_create_symbolic_icon (_tmp0_, 128);
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	pix = _tmp1_;
#line 495 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pix;
#line 495 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 4976 "util-app.c"
		const gchar* _tmp3_;
		GThemedIcon* _tmp4_;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = name;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = (GThemedIcon*) g_themed_icon_new (_tmp3_);
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pix);
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
		pix = (GIcon*) _tmp4_;
#line 4987 "util-app.c"
	}
#line 498 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = pix;
#line 498 "/extra-data/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4993 "util-app.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 5000 "util-app.c"
		int i;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 5008 "util-app.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 5020 "util-app.c"
}



